#include <allegro5/allegro.h>
#include <allegro5/allegro_ttf.h>
#include <allegro5/allegro_font.h>
#include <allegro5/allegro_image.h>
#include <allegro5/allegro_native_dialog.h>

bool MenuState = true;
bool OptionsState = false;
bool CreditsState = false;
bool GameState = false;
const bool ToolbarState = true; 
bool InventoryState = false;
bool EquipmentState = false;
bool QuestState = false;
bool StatsState = false;
bool DateTimeLocationState = false;
bool DateTimeLocationRedraw = false;
bool DateTimeLocationStart = false;

int Minute;
int Hour;
int Day = 1;
int Month = 1;
int Year = 1221;
bool AmPm = false;

int Xoff = 0;
int Yoff = 0;

int MapX = 25;
int MapY = 25;
int MapSize = 625;
int TileSize = 32;

ALLEGRO_BITMAP *TileSheet;
ALLEGRO_BITMAP *PlayerTileSheet;

void LevelSelect();
void Level1();
void Level2();
void Level3();

int Map[25][25];
int PlayerMap[25][25];

ALLEGRO_TIMER *Timer;
bool Redraw = true;
bool MapStart = true;
const float FPS = 60;

ALLEGRO_DISPLAY *MenuDisplay;
ALLEGRO_DISPLAY *OptionsDisplay;
ALLEGRO_DISPLAY *CreditsDisplay;
ALLEGRO_DISPLAY *GameDisplay;
ALLEGRO_DISPLAY *ToolbarDisplay;
ALLEGRO_DISPLAY *InventoryDisplay;
ALLEGRO_DISPLAY *EquipmentDisplay;
ALLEGRO_DISPLAY *QuestDisplay;
ALLEGRO_DISPLAY *StatsDisplay;
ALLEGRO_DISPLAY *DateTimeLocationDisplay;

ALLEGRO_EVENT_QUEUE *EventQueue;
ALLEGRO_EVENT Event;

ALLEGRO_EVENT_QUEUE *ToolbarEventQueue;
ALLEGRO_EVENT ToolbarEvent;

ALLEGRO_EVENT_QUEUE *InventoryEventQueue;
ALLEGRO_EVENT InventoryEvent;

ALLEGRO_EVENT_QUEUE *EquipmentEventQueue;
ALLEGRO_EVENT EquipmentEvent;

ALLEGRO_EVENT_QUEUE *QuestEventQueue;
ALLEGRO_EVENT QuestEvent;

ALLEGRO_EVENT_QUEUE *StatsEventQueue;
ALLEGRO_EVENT StatsEvent;

ALLEGRO_EVENT_QUEUE *DateTimeLocationEventQueue;
ALLEGRO_EVENT DateTimeLocationEvent;


void Menu();
void Game();
void Options();
void Credits();

int X;
int Y;

void PlayerMovement();

int main()
{
    al_init();
    al_init_image_addon();
    al_install_keyboard();
    al_install_mouse();
    al_init_font_addon();
    al_init_ttf_addon();
    
    Timer = al_create_timer(1.0 / FPS);

    EventQueue = al_create_event_queue();
    ToolbarEventQueue = al_create_event_queue();
    InventoryEventQueue = al_create_event_queue();
    EquipmentEventQueue = al_create_event_queue();
    QuestEventQueue = al_create_event_queue();
    StatsEventQueue = al_create_event_queue();
    DateTimeLocationEventQueue = al_create_event_queue();
    
    al_register_event_source(EventQueue, al_get_keyboard_event_source());

    Menu();
    if(GameState)
    {
         Game();
    }
    else if(OptionsState)
    {
         Options();
    }
    else if(CreditsState)
    {
         Credits();
    }

    return 0;
}

void Menu()
{
    MenuDisplay = al_create_display(640, 480);
    
    al_register_event_source(EventQueue, al_get_display_event_source(MenuDisplay));
    
    ALLEGRO_BITMAP *Image = NULL;
    Image = al_load_bitmap("MainMenu.png");
    
    al_set_window_title(MenuDisplay, "Main Menu");
    
    while(MenuState)
    {
         al_draw_bitmap(Image, 0, 0, 0);
         al_flip_display();

         al_wait_for_event(EventQueue, &Event);

         if(Event.type == ALLEGRO_EVENT_DISPLAY_CLOSE)
         {
              MenuState = false;
         }
         if(Event.type == ALLEGRO_EVENT_KEY_DOWN)
         {
              if(Event.keyboard.keycode == ALLEGRO_KEY_ESCAPE)
              {
                   MenuState = false;
              }
              else if(Event.keyboard.keycode == ALLEGRO_KEY_1 || Event.keyboard.keycode == ALLEGRO_KEY_PAD_1)
              {
                   MenuState = false;
                   al_destroy_display(MenuDisplay);
                   GameState = true;
                   
              }
              else if(Event.keyboard.keycode == ALLEGRO_KEY_2 || Event.keyboard.keycode == ALLEGRO_KEY_PAD_2)
              {
                   al_show_native_message_box(al_get_current_display(), 
                                 "Main Menu", 
                                 "Load Game", 
                                 "Starting a Old Game",
                                 NULL, 0);
              }
              else if(Event.keyboard.keycode == ALLEGRO_KEY_3 || Event.keyboard.keycode == ALLEGRO_KEY_PAD_3)
              {
                   MenuState = false;
                   al_destroy_display(MenuDisplay);
                   OptionsState = true;
              }
              else if(Event.keyboard.keycode == ALLEGRO_KEY_4 || Event.keyboard.keycode == ALLEGRO_KEY_PAD_4)
              {
                   
                   MenuState = false;
                   al_destroy_display(MenuDisplay);
                   CreditsState = true;
              }
              else if(Event.keyboard.keycode == ALLEGRO_KEY_5 || Event.keyboard.keycode == ALLEGRO_KEY_PAD_5)
              {
                   MenuState = false;
              }
         }
    }
}

void Options()
{
    OptionsDisplay = al_create_display(640, 480);
    al_set_window_title(OptionsDisplay, "Options");
    
    al_register_event_source(EventQueue, al_get_display_event_source(OptionsDisplay));
    
    ALLEGRO_BITMAP *Image = NULL;
    Image = al_load_bitmap("Options.png");
    while(OptionsState)
    {
         al_flip_display();
         
         al_draw_bitmap(Image, 0, 0, 0);

         al_wait_for_event(EventQueue, &Event);
         
         if(Event.type == ALLEGRO_EVENT_DISPLAY_CLOSE)
         {
              OptionsState = false;
         }
         if(Event.type == ALLEGRO_EVENT_KEY_DOWN)
         {
              if(Event.keyboard.keycode == ALLEGRO_KEY_ESCAPE)
              {
                   MenuState = true;
                   al_destroy_display(OptionsDisplay);
                   OptionsState = false;
              }
         }
    }
    main();
}

void Credits()
{
    CreditsDisplay = al_create_display(640, 480);
    al_set_window_title(CreditsDisplay, "Credits");
    
    al_register_event_source(EventQueue, al_get_display_event_source(CreditsDisplay));
    
    ALLEGRO_BITMAP *Image = NULL;
    Image = al_load_bitmap("Credits.png");
    while(CreditsState)
    {
         al_flip_display();
         
         al_draw_bitmap(Image, 0, 0, 0);

         al_wait_for_event(EventQueue, &Event);
         
         if(Event.type == ALLEGRO_EVENT_DISPLAY_CLOSE)
         {
              CreditsState = false;
         }
         if(Event.type == ALLEGRO_EVENT_KEY_DOWN)
         {
              if(Event.keyboard.keycode == ALLEGRO_KEY_ESCAPE)
              {
                   MenuState = true;
                   al_destroy_display(CreditsDisplay);
                   CreditsState = false;
              }
         }
    }
    main();
}

void Game()
{
    int InventoryCounter = 0;
    bool InventoryRegister = false;
    
    int EquipmentCounter = 0;
    bool EquipmentRegister = false;
    
    int DateTimeLocationCounter = 0;
    bool DateTimeLocationRegister = false;
    
    GameDisplay = al_create_display(800, 800);
    al_set_window_title(GameDisplay, "Game");
    
    ToolbarDisplay = al_create_display(160, 64);
    al_set_window_title(ToolbarDisplay, "Toolbar");
    
    
    al_register_event_source(EventQueue, al_get_display_event_source(GameDisplay));
    al_register_event_source(EventQueue, al_get_timer_event_source(Timer));
    
    al_register_event_source(ToolbarEventQueue, al_get_display_event_source(ToolbarDisplay));
    al_register_event_source(ToolbarEventQueue, al_get_timer_event_source(Timer));
    al_register_event_source(ToolbarEventQueue, al_get_mouse_event_source());
    
    
    TileSheet = al_load_bitmap("Tiles.png");
    
    PlayerTileSheet = al_load_bitmap("PlayerTiles.png");
    
    ALLEGRO_BITMAP *ToolbarImage = NULL;
    ToolbarImage = al_load_bitmap("Toolbar.png");
    
    ALLEGRO_BITMAP *InventoryImage = NULL;
    InventoryImage = al_load_bitmap("Inventory.png");
    
    ALLEGRO_BITMAP *EquipmentImage = NULL;
    EquipmentImage = al_load_bitmap("Equipment.png");
    
    ALLEGRO_BITMAP *DateTimeLocationImage = NULL;
    DateTimeLocationImage = al_load_bitmap("DateTimeLocation.png");
    
    ALLEGRO_FONT *font = al_load_ttf_font("tahoma.ttf", 16, 0 );
    
    al_start_timer(Timer);
    while(GameState)
    {
         LevelSelect();
         
         al_flip_display();
         
         al_set_target_backbuffer(ToolbarDisplay);
         al_draw_bitmap(ToolbarImage, 0, 0, 0);

         al_wait_for_event(EventQueue, &Event);
         al_wait_for_event(ToolbarEventQueue, &ToolbarEvent);
         
         PlayerMovement();
         
         if(Event.type == ALLEGRO_EVENT_TIMER)
         {
              Redraw = true;
         }
         
         if(Event.type == ALLEGRO_EVENT_DISPLAY_CLOSE)
         {
              GameState = false;
         }
         else if(Event.type == ALLEGRO_EVENT_KEY_DOWN)
         {
              if(Event.keyboard.keycode == ALLEGRO_KEY_ESCAPE)
              {
                   GameState = false;
              }
         }
         
         if(ToolbarEvent.type == ALLEGRO_EVENT_MOUSE_BUTTON_DOWN && InventoryCounter == 0)
         {
              if(ToolbarEvent.mouse.x > 0 && ToolbarEvent.mouse.x < 32 &&
                 ToolbarEvent.mouse.y > 0 && ToolbarEvent.mouse.y < 32)
              {
                   InventoryState = true;
                   InventoryCounter = 1;
              }
         }
         if(ToolbarEvent.type == ALLEGRO_EVENT_MOUSE_BUTTON_DOWN && EquipmentCounter == 0)
         {
              if(ToolbarEvent.mouse.x > 32 && ToolbarEvent.mouse.x < 64 &&
                 ToolbarEvent.mouse.y > 0 && ToolbarEvent.mouse.y < 32)
              {
                   EquipmentState = true;
                   EquipmentCounter = 1;
              }
         }
         if(ToolbarEvent.type == ALLEGRO_EVENT_MOUSE_BUTTON_DOWN && DateTimeLocationCounter == 0)
         {
              if(ToolbarEvent.mouse.x > 128 && ToolbarEvent.mouse.x < 160 &&
                 ToolbarEvent.mouse.y > 0 && ToolbarEvent.mouse.y < 32)
              {
                   DateTimeLocationState = true;
                   DateTimeLocationCounter = 1;
              }
         }
         
         if(InventoryRegister)
         {
              al_register_event_source(InventoryEventQueue, al_get_display_event_source(InventoryDisplay));
         }
         
         if(InventoryEvent.type == ALLEGRO_EVENT_DISPLAY_CLOSE)
         {
              InventoryCounter = 0;
              InventoryRegister = false;
              InventoryState = false;
              al_destroy_display(InventoryDisplay);
         }
         
         if(InventoryState)
         {
              InventoryDisplay = al_create_display(160, 160);
              al_set_window_title(InventoryDisplay, "Inventory");
              al_set_target_backbuffer(InventoryDisplay);
              al_draw_bitmap(InventoryImage, 0, 0, 0);
              InventoryState = false;
              InventoryRegister = true;
         }
         
         if(EquipmentRegister)
         {
              al_register_event_source(EquipmentEventQueue, al_get_display_event_source(EquipmentDisplay));
         }
         
         if(EquipmentEvent.type == ALLEGRO_EVENT_DISPLAY_CLOSE)
         {
              EquipmentCounter = 0;
              EquipmentRegister = false;
              EquipmentState = false;
              al_destroy_display(EquipmentDisplay);
         }
         
         if(EquipmentState)
         {
              EquipmentDisplay = al_create_display(160, 64);
              al_set_window_title(EquipmentDisplay, "Equipment");
              al_set_target_backbuffer(EquipmentDisplay);
              al_draw_bitmap(EquipmentImage, 0, 0, 0);
              EquipmentState = false;
              EquipmentRegister = true;
         }
         
         if(DateTimeLocationRegister)
         {
              al_register_event_source(DateTimeLocationEventQueue, al_get_display_event_source(DateTimeLocationDisplay));
              al_register_event_source(DateTimeLocationEventQueue, al_get_timer_event_source(Timer));
         }
         
         if(DateTimeLocationEvent.type == ALLEGRO_EVENT_DISPLAY_CLOSE)
         {
              DateTimeLocationCounter = 0;
              DateTimeLocationRegister = false;
              DateTimeLocationState = false;
              al_destroy_display(DateTimeLocationDisplay);
         }
         
         if(DateTimeLocationState)
         {
              DateTimeLocationDisplay = al_create_display(192, 160);
              al_set_window_title(DateTimeLocationDisplay, "Date Time Location");
              DateTimeLocationState = false;
              DateTimeLocationRegister = true;
              DateTimeLocationStart = true;
         }
         if(DateTimeLocationRedraw && al_is_event_queue_empty(DateTimeLocationEventQueue) || DateTimeLocationStart)
         {
              al_set_target_backbuffer(DateTimeLocationDisplay);
              al_draw_bitmap(DateTimeLocationImage, 0, 0, 0);
              
              al_draw_textf(font, al_map_rgb(153, 76, 0), 16, 40, 0, "%d / %d / %d", Day, Month, Year);
         }
         
         if(Redraw && al_is_event_queue_empty(EventQueue) || MapStart)
         {
              Redraw = false;
              for(int Drawx = 0; Drawx < MapX; Drawx++)
              {
                   for(int Drawy = 0; Drawy < MapY; Drawy++)
                   {
                        al_set_target_backbuffer(GameDisplay);
                        al_draw_bitmap_region(TileSheet, Map[Drawy][Drawx] * TileSize, 0, TileSize, 32, Drawx * TileSize,
                                              Drawy * TileSize, 0);
                   }
              }
              for(int Drawx = 0; Drawx < MapX; Drawx++)
              {
                   for(int Drawy = 0; Drawy < MapY; Drawy++)
                   {
                        al_convert_mask_to_alpha(PlayerTileSheet, al_map_rgb(255, 0, 255));
                        al_draw_bitmap_region(PlayerTileSheet, PlayerMap[Drawy][Drawx] * TileSize, 0, TileSize, 32, Drawx * TileSize,
                                              Drawy * TileSize, 0);
                   }
              }
              MapStart = false;
         }
    }
}

void PlayerMovement()
{
    if(Event.type == ALLEGRO_EVENT_KEY_DOWN)
         { 
              if(Event.keyboard.keycode == ALLEGRO_KEY_DOWN)
              {
                   int Y2 = Y + 1;
                   
                   if(Map[Y2][X] == 5)
                   {
                        PlayerMap[Y][X] = 5;
                        Y--;
                        PlayerMap[Y][X] = 0;
                   }
              }
         }
}

void LevelSelect()
{

    int ArrayLevelSelect[10][10] = {
    {1, 2, 3, 4, 5, 6, 7, 8, 9, 10},
    {11, 12, 13, 14, 15, 16, 17, 18, 19, 20},
    {21, 22, 23, 24, 25, 26, 27, 28, 29, 30},
    {31, 32, 33, 34, 35, 36, 37, 38, 39, 40},
    {41, 42, 43, 44, 45, 46, 47, 48, 49, 50},
    {51, 52, 53, 54, 55, 56, 57, 58, 59, 60},
    {61, 62, 63, 64, 65, 66, 67, 68, 69, 70},
    {71, 72, 73, 74, 75, 76, 77, 78, 79, 80},
    {81, 82, 83, 84, 85, 86, 87, 88, 89, 90},
    {91, 92, 93, 94, 95, 96, 97, 98, 99, 100}
    };
    
    int LevelX;
    int LevelY;
    
    bool FirstTime = true;
    
    if(FirstTime)
    {
         LevelY = 0;
         LevelX = 0;
         FirstTime = false;
    }
    
    if(ArrayLevelSelect[LevelY][LevelX] == 1)
    {
         Level1();
    }
    else if(ArrayLevelSelect[LevelY][LevelX] == 2)
    {
         Level2();
    }
}
void Level1()
{
int Level[25][25] = {
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10,10,10,10,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10, 5, 5, 5,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10, 5, 5, 5,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,10, 5, 5, 5,10, 5, 5, 5,10},
{10, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10,10,33,10,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 7,10},
{10,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,10},
{10,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,34,11,11,11, 5, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10,11,11,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11, 5,11,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,35,10},
{10,11, 5,34, 5,11,11,11,11,11, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,35, 5, 5,10},
{10,11,11, 5, 5, 5,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,35, 5,10},
{10,11,11,11,11,11,11,11,11,11,11, 5, 8, 5, 5, 5, 5, 5, 5, 5, 5, 5,35, 5,10},
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10}
};

X = 2;
Y = 2;

int PlayerLevel[25][25] = {
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10,10,10,10,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10, 5, 5, 5,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10, 5, 5, 5,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,10, 5, 5, 5,10, 5, 5, 5,10},
{10, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10,10,33,10,10, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 7,10},
{10,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,10},
{10,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,34,11,11,11, 5, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10,11,11,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,11,11, 5,11,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,35,10},
{10,11, 5,34, 5,11,11,11,11,11, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,35, 5, 5,10},
{10,11,11, 5, 5, 5,11,11,11,11, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,35, 5,10},
{10,11,11,11,11,11,11,11,11,11,11, 5, 8, 5, 5, 5, 5, 5, 5, 5, 5, 5,35, 5,10},
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10}
};

memcpy(Map, Level, sizeof(Level));
memcpy(PlayerMap, PlayerLevel, sizeof(PlayerLevel));
}

void Level2()
{
int Level[25][25] = {
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5,34, 5, 5, 5, 5, 5,34,34,34,34,34, 5, 5, 5,35, 5,34, 5, 5,10},
{10, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5,34, 5, 5,34, 5, 5, 5,34,34,34, 5, 5, 5, 5,34,34, 5, 5, 5, 5,10},
{10, 5, 5, 5,34, 5, 5,34, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34,34, 5, 5,34, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5,34, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5,34, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 9,34, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 7,10},
{10, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34,34, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34,34, 5, 5, 5, 5,34,34,34, 5, 5,34,34,34, 5, 5,34, 5,34,34, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,34, 5, 5, 5, 5,10},
{10, 5,10,10,10,10,10, 5, 5, 5,34, 5, 5, 5, 5, 5,34, 5, 5,34, 5, 5, 5, 5,10},
{10, 5,10, 5, 5, 5,10, 5, 5, 5, 5, 5,34,34,34,34,34, 5, 5,34,34, 5, 5, 5,10},
{10, 5,10, 5, 5, 5,10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5,10},
{10, 5,10, 5, 5, 5,10, 5, 5,34, 5, 5, 5, 5, 5,34,34, 5, 5, 5,34, 5,34, 5,10},
{10, 5,10,10,33,10,10, 5,34,34, 5, 5,34, 5, 5, 5,34, 5, 5, 5, 5, 5,34, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,34,34,34, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 8,35, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10}
};

int PlayerLevel[25][25] = {
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 0, 5, 5,34, 5, 5, 5, 5, 5,34,34,34,34,34, 5, 5, 5,35, 5,34, 5, 5,10},
{10, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5,34, 5, 5,34, 5, 5, 5,34,34,34, 5, 5, 5, 5,34,34, 5, 5, 5, 5,10},
{10, 5, 5, 5,34, 5, 5,34, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34,34, 5, 5,34, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5,34, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 5,34, 5, 5, 5, 5, 5, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10, 9,34, 5, 5, 5,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 7,10},
{10, 5,34,34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34,34, 5,34, 5, 5, 5, 5,10},
{10, 5, 5,34,34, 5, 5, 5, 5,34,34,34, 5, 5,34,34,34, 5, 5,34, 5,34,34, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5,34, 5, 5, 5, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5,34, 5, 5, 5, 5,10},
{10, 5,10,10,10,10,10, 5, 5, 5,34, 5, 5, 5, 5, 5,34, 5, 5,34, 5, 5, 5, 5,10},
{10, 5,10, 5, 5, 5,10, 5, 5, 5, 5, 5,34,34,34,34,34, 5, 5,34,34, 5, 5, 5,10},
{10, 5,10, 5, 5, 5,10, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,34, 5, 5, 5,10},
{10, 5,10, 5, 5, 5,10, 5, 5,34, 5, 5, 5, 5, 5,34,34, 5, 5, 5,34, 5,34, 5,10},
{10, 5,10,10,33,10,10, 5,34,34, 5, 5,34, 5, 5, 5,34, 5, 5, 5, 5, 5,34, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 5,34, 5, 5, 5, 5, 5, 5, 5,34,34,34, 5,10},
{10, 5, 5, 5, 5, 5, 5, 5, 5,34,34, 5, 8,35, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,10},
{10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10}
};

memcpy(Map, Level, sizeof(Level));
memcpy(PlayerMap, PlayerLevel, sizeof(PlayerLevel));
}

void Level3()
{


//memcpy(Map, Level, sizeof(Level));
//memcpy(PlayerMap, PlayerLevel, sizeof(PlayerLevel));
}
